@@ -27,7 +27,7 @@ class Command(BaseCommand):
     ])
 
     def add_arguments(self, parser):
-        super(Command, self).add_arguments(parser)
+        super().add_arguments(parser)
         parser.add_argument(
             '--no-apps', action='store_true', dest='no_apps',
             default=False, help="Do not automatically include apps.")
@@ -54,7 +54,7 @@ class Command(BaseCommand):
             self.ignores = getattr(settings, 'VALIDATE_TEMPLATES_IGNORES')
 
         style = color_style()
-        template_dirs = set(get_template_setting('DIRS'))
+        template_dirs = set(get_template_setting('DIRS', []))
         template_dirs |= set(options['includes'])
         template_dirs |= set(getattr(settings, 'VALIDATE_TEMPLATES_EXTRA_TEMPLATE_DIRS', []))
 
